.. :changelog:

History
-------

0.1.0 (2018-04-10)
++++++++++++++++++

* Models for Phenotype Ontologies
* REST API
* GraphQL Nodes
* Sync methods for PURL of MONDO, HPO, NCIT

0.1.1 (2018-04-10)
++++++++++++++++++

* Updated sync to sync_ontology to make it more descriptive

0.1.2 (2018-04-10)
++++++++++++++++++

* Added better support for MONDO. A few oddities were causing errors w/ pronto.

0.1.3 (2018-04-18)
++++++++++++++++++

* Updated 3rd party libs

0.1.4 (2018-05-16)
++++++++++++++++++

* Updated setup.py to read from requirements.txt
